@@ -1,7 +1,9 @@
 import warnings
+
 from django import forms
-from django.utils import six
+from django.forms import BoundField
 from django.template import loader
+from .conf import settings
 
 
 class BaseForm:
@@ -23,13 +25,13 @@ class BaseForm:
 
         super(self._ref_class, self).__init__(*kargs, **kwargs)
 
-        for field in six.itervalues(self.fields):
+        for field in self.fields.values():
             field._request = self.request
 
         self.ajax_fields_populate()
 
     def ajax_fields_populate(self):
-        for name, field in six.iteritems(self.fields):
+        for name, field in self.fields.items():
             if hasattr(field, 'ajax_populate'):
                 field.ajax_populate(self, name)
 
@@ -53,7 +55,7 @@ class BaseForm:
         else:
             _template_name = self.template
         " Helper function for fieldstring fields data from form. "
-        bound_fields = [forms.forms.BoundField(self, field, name) for name, field in self.fields.items()]
+        bound_fields = [BoundField(self, field, name) for name, field in self.fields.items()]
 
         c = dict(form=self, bound_fields=bound_fields)
         t = loader.get_template(_template_name)
@@ -78,7 +80,7 @@ class BaseForm:
             value_name: name of field, property or method in queryset
                 instance model, that will be set as value in dropdown
             empty_label: value, that will be set for empty line,
-                by default it set to '-------'
+                by default it set to settings.DEFAULT_CHOICE_LABEL
             empty_value: value, that will be set for empty line,
                 by default it set to ''
 
@@ -88,7 +90,7 @@ class BaseForm:
         field.choices = []
         if add_empty:
             field.choices.append((empty_value or '',
-                                  empty_label if empty_label is not None else '-------'))
+                                  empty_label if empty_label is not None else settings.DEFAULT_CHOICE_LABEL))
 
         def _get_field(obj, fieldname=None):
             if fieldname:
