@@ -1,6 +1,12 @@
 from django import forms
 from django.db import models
-from django.db.models.fields import Field, FieldDoesNotExist
+from django.db.models.fields import Field
+
+try:
+    from django.db.models.fields import FieldDoesNotExist
+except ImportError:
+    from django.core.exceptions import FieldDoesNotExist
+
 from django.db.models.manager import Manager
 
 from .base import BaseForm
@@ -27,7 +33,7 @@ class RequestForm(BaseForm, forms.Form):
                 field = instance._meta.get_field(key)
                 if isinstance(field, (models.ImageField, models.FileField)):
                     if data[key] is not None:
-                        if data[key] == False:
+                        if data[key] is False:
                             data[key] = None
                         setattr(instance, key, data[key])
                 elif isinstance(field, (models.ForeignKey, models.IPAddressField, models.GenericIPAddressField)):
